@@ -131,6 +131,7 @@ modern_classmap = [('valo', 'sw', [(None,'(.*)','valo'),
 			 (None,'(.*Cé)','nalle'),
 		         (None,'(.*[iu]e)','nalle'),
 		         ('tt','(.*t)te','atte'),
+		         ('pp','(.*p)pe','hjerppe'),
 		         ('kk','(.*k)ke','nukke')]),
 	('kala', 'sw',   [(None,'(.*)A','kala'),
 			('tt','(.*t)tA','aitta'),
@@ -326,11 +327,12 @@ modern_classmap = [('valo', 'sw', [(None,'(.*)','valo'),
 	('inttää', 'sw', [('tt','(.*t)tAA','inttää'),
 	                    ('t','(.*)tAA','itää')]),
 	('sulaa', 'sw', [(None,'(.*C)AA','sulaa'),
-	                   ('nt','(.*n)tAA','kyntää'),
+	                   ('nt','(.*n)tAA','kyntää1'),
 		         ('tt','(.*t)tAA','autioittaa'),
 		         ('t','(.*)tAA','kulahtaa'),
 		         ('k>','(.*C)kAA','purkaa')]),
 	('hohtaa', 'sw', [('tt','(.*t)tAA','jättää'),
+	                   ('nt','(.*n)tAA','kyntää2'),
 	                    ('t','(.*)tAA','hohtaa')]),
 	('hujahtaa', 'sw', [('t','(.*V)htAA','hujahtaa')]),
 	('kirjoittaa', 'sw', [('tt','(.*V)ittAA','kirjoittaa'),
@@ -359,7 +361,9 @@ modern_classmap = [('valo', 'sw', [(None,'(.*)','valo'),
 			('k>','(.*)kAA','jakaa'),
 			('t','(.*)tAA','raataa')]),
 	('kaikaa', '-', [(None,'(.*C)AA','kapsaa')]),
-	('soutaa', 'sw', [('t','(.*)tAA','soutaa')]),
+	('soutaa', 'sw', [('lt','(.*l)tAA','yltää'),
+                          ('nt','(.*n)tAA','entää'),
+                          ('t','(.*)tAA','soutaa')]),
 	('saartaa', '-', [(None,'(.*r)tAA','saartaa')]),
 	('laskea', 'sw', [(None,'(.*C)eA','laskea'),
 	                    ('nk','(.*n)keA','tunkea'),
